/*

What this library does: Knocks down buildings.

Datums:

	JEF_COL_master

		vars

			PASS_TAG

				A text string or number meant to make JEF_col datums have a unique tag, along with the objects they contain

		procs

			Get_Det(T)

				returns null or a JEF_col datum (unless there is a datum/atom with the same tag, in which case it returns the first
				                                 object it can find)

				Args:

					T: The tag of the object whose collapsing handler thing you wish to find

	JEF_col

		vars

			speed: The speed at which you wish the object to fall, in pixels. Must be less than or equal to 32, and greater than 0

			contents: A list of the objects that will collapse upon calling the Demolish() proc

		procs

			Demolish()

				It knocks down the movable atoms contained within its contents var

				returns null always

				args: None

			UDT()

				Updates the tags and animate_movement variables of all objects inside its contents. Must be called before
				demolition or the animate_movement vars of the objects must be manually edited. Must be called for the
				JEF_COL_master.Get_Det() proc to work properly.

				returns null

				args: none

			Sort()

				returns the bases of the building etc. with respect to the y-axis

				args: none

			get_bases()

				returns: The bases of the object with respect to the y-axis

				args: None

				Removes bases from the JEF_col's contents

			On_Tier(list/bases)

				returns null

				args: A list of the bases of the building that is collapsing. They will be deleted after this proc.

				Called when a set of bases !will! be deleted

				By default, this does absolutely nothing.

			On_Collapse(list/bases)

				returns null

				args: A list of the bases of the building that is collapsing. They will be deleted after this proc.

				Called when the last set of bases !will! be deleted

				By default, this does absolutely nothing.

			Pre_Collapse(list/bases)

				returns null

				args: A list of the bases of the building that is collapsing. They will be deleted after this proc.

				Called before the building starts falling

				By default, this does absolutely nothing.

			get_tier(var/Z as num)

				returns the list of movable atoms in Z tier of the building

				args: Z: The height (in building height which = tier height - base of building height) of the tier you want

			get_tiers_less_equal(var/Z as num)

				returns the list of movable atoms in Z and below tier of the building

				args: Z: The height (in building height which = tier height - base of building height) of the tiers you want
						 Also includes every tier below Z

			get_tiers_greater_equal(var/Z as num)

				returns the list of movable atoms in Z and above tier of the building

				args: Z: The height (in building height which = tier height - base of building height) of the tiers you want
						 Also includes every tier above Z

			get_height()

				returns the height of the building in question. Will cause errors if the JEF_COL has no contents

			get_tile_height(atom/movable/A)

				returns the height of A with respect to the building (A.y - base of building.y)

				args: A: The movable atom you wish to find the height of with respect to the building. Does NOT have to be a part
						 of the building itself!


Global vars:

	JEF_col

		The worlds JEF_COL_master datum. Used to call Get_Det() and edit the PASS_TAG var at runtime.



Notes:

	Do not edit the tags of an object in a building if you need to call Get_Det()

	Call the JEF_COL.UDT() proc every time an object is added to its contents if you need to use the Get_Det() proc

	On_Tier() and On_Collapse() can be used for graphical effects, such as smoke.

*/